@@ -452,7 +452,7 @@ on_play_activate (GtkWidget *button, gpointer user_data)
   } else if (pipeline && GST_STATE (pipeline) == GST_STATE_PAUSED &&
 			 current_track != seek_to_track) {
     if (!gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (track_store),
-                                          &current_iter, NULL, current_track))
+                                          &current_iter, NULL, seek_to_track))
         return;
 	set_gst_ui_and_play ();
   } else if (setup (&err)) {
